@@ -168,6 +168,7 @@ g_file_create_flags_get_type (void)
       static const GFlagsValue values[] = {
         { G_FILE_CREATE_NONE, "G_FILE_CREATE_NONE", "none" },
         { G_FILE_CREATE_PRIVATE, "G_FILE_CREATE_PRIVATE", "private" },
+        { G_FILE_CREATE_REPLACE_DESTINATION, "G_FILE_CREATE_REPLACE_DESTINATION", "replace-destination" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -372,6 +373,7 @@ g_io_error_enum_get_type (void)
         { G_IO_ERROR_HOST_NOT_FOUND, "G_IO_ERROR_HOST_NOT_FOUND", "host-not-found" },
         { G_IO_ERROR_WOULD_MERGE, "G_IO_ERROR_WOULD_MERGE", "would-merge" },
         { G_IO_ERROR_FAILED_HANDLED, "G_IO_ERROR_FAILED_HANDLED", "failed-handled" },
+        { G_IO_ERROR_TOO_MANY_OPEN_FILES, "G_IO_ERROR_TOO_MANY_OPEN_FILES", "too-many-open-files" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
