@@ -506,6 +506,8 @@ get_xattrs (const char            *path,
 		g_free (escaped_attr);
 	      
 	      get_one_xattr (path, info, gio_attr, attr, follow_symlinks);
+
+	      g_free (gio_attr);
 	    }
 	      
 	  len = strlen (attr) + 1;
@@ -823,7 +825,7 @@ _g_local_file_info_get_parent_info (const char            *dir,
 #endif
 	  parent_info->owner = statbuf.st_uid;
 	  parent_info->device = statbuf.st_dev;
-          /* No need to find trash dir if its not writable anyway */
+          /* No need to find trash dir if it's not writable anyway */
           if (parent_info->writable &&
               g_file_attribute_matcher_matches (attribute_matcher, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH))
             parent_info->has_trash_dir = _g_local_file_has_trash_dir (dir, statbuf.st_dev);
@@ -938,6 +940,8 @@ set_info_from_stat (GFileInfo             *info,
 #endif
 #if defined (HAVE_STRUCT_STAT_ST_BLOCKS)
   g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_UNIX_BLOCKS, statbuf->st_blocks);
+  g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_ALLOCATED_SIZE,
+                                    statbuf->st_blocks * G_GUINT64_CONSTANT (512));
 #endif
   
   g_file_info_set_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED, statbuf->st_mtime);
@@ -1677,9 +1681,9 @@ _g_local_file_info_get (const char             *basename,
 }
 
 GFileInfo *
-_g_local_file_info_get_from_fd (int      fd,
-				char    *attributes,
-				GError **error)
+_g_local_file_info_get_from_fd (int         fd,
+				const char *attributes,
+				GError    **error)
 {
   GLocalFileStat stat_buf;
   GFileAttributeMatcher *matcher;
@@ -2167,7 +2171,7 @@ _g_local_file_info_set_attributes  (char                 *filename,
 #ifdef HAVE_UTIMES
   GFileAttributeValue *mtime, *mtime_usec, *atime, *atime_usec;
 #endif
-#if defined (HAVE_CHOWN) && defined (HAVE_UTIMES)
+#if defined (HAVE_CHOWN) || defined (HAVE_UTIMES)
   GFileAttributeStatus status;
 #endif
   gboolean res;
