@@ -656,13 +656,13 @@ g_option_context_get_help (GOptionContext *context,
   list = context->groups;
   while (list != NULL)
     {
-      GOptionGroup *group = list->data;
-      for (i = 0; i < group->n_entries; i++)
+      GOptionGroup *g = list->data;
+      for (i = 0; i < g->n_entries; i++)
 	{
-	  entry = &group->entries[i];
+	  entry = &g->entries[i];
 	  if (g_hash_table_lookup (shadow_map, entry->long_name) && 
 	      !(entry->flags & G_OPTION_FLAG_NOALIAS))
-	    entry->long_name = g_strdup_printf ("%s-%s", group->name, entry->long_name);
+	    entry->long_name = g_strdup_printf ("%s-%s", g->name, entry->long_name);
 	  else  
 	    g_hash_table_insert (shadow_map, (gpointer)entry->long_name, entry);
 
@@ -695,14 +695,14 @@ g_option_context_get_help (GOptionContext *context,
 
   while (list != NULL)
     {
-      GOptionGroup *group = list->data;
+      GOptionGroup *g = list->data;
       
       /* First, we check the --help-<groupname> options */
-      len = _g_utf8_strwidth ("--help-", -1) + _g_utf8_strwidth (group->name, -1);
+      len = _g_utf8_strwidth ("--help-", -1) + _g_utf8_strwidth (g->name, -1);
       max_length = MAX (max_length, len);
 
       /* Then we go through the entries */
-      len = calculate_max_length (group);
+      len = calculate_max_length (g);
       max_length = MAX (max_length, len);
       
       list = list->next;
@@ -727,12 +727,12 @@ g_option_context_get_help (GOptionContext *context,
       
       while (list)
 	{
-	  GOptionGroup *group = list->data;
+	  GOptionGroup *g = list->data;
 
-	  if (group_has_visible_entries (context, group, FALSE))
+	  if (group_has_visible_entries (context, g, FALSE))
 	    g_string_append_printf (string, "  --help-%-*s %s\n",
-				    max_length - 5, group->name,
-				    TRANSLATE (group, group->help_description));
+				    max_length - 5, g->name,
+				    TRANSLATE (g, g->help_description));
 	  
 	  list = list->next;
 	}
@@ -761,15 +761,15 @@ g_option_context_get_help (GOptionContext *context,
 
       while (list)
 	{
-	  GOptionGroup *group = list->data;
+	  GOptionGroup *g = list->data;
 
-	  if (group_has_visible_entries (context, group, FALSE))
+	  if (group_has_visible_entries (context, g, FALSE))
 	    {
-	      g_string_append (string, group->description);
+	      g_string_append (string, g->description);
 	      g_string_append (string, "\n");
-	      for (i = 0; i < group->n_entries; i++)
-		if (!(group->entries[i].flags & G_OPTION_FLAG_IN_MAIN))
-		  print_entry (group, max_length, &group->entries[i], string);
+	      for (i = 0; i < g->n_entries; i++)
+		if (!(g->entries[i].flags & G_OPTION_FLAG_IN_MAIN))
+		  print_entry (g, max_length, &g->entries[i], string);
 	  
 	      g_string_append (string, "\n");
 	    }
@@ -794,12 +794,12 @@ g_option_context_get_help (GOptionContext *context,
 
       while (list != NULL)
 	{
-	  GOptionGroup *group = list->data;
+	  GOptionGroup *g = list->data;
 
 	  /* Print main entries from other groups */
-	  for (i = 0; i < group->n_entries; i++)
-	    if (group->entries[i].flags & G_OPTION_FLAG_IN_MAIN)
-	      print_entry (group, max_length, &group->entries[i], string);
+	  for (i = 0; i < g->n_entries; i++)
+	    if (g->entries[i].flags & G_OPTION_FLAG_IN_MAIN)
+	      print_entry (g, max_length, &g->entries[i], string);
 	  
 	  list = list->next;
 	}
@@ -816,6 +816,7 @@ g_option_context_get_help (GOptionContext *context,
   return g_string_free (string, FALSE);
 }
 
+G_GNUC_NORETURN
 static void
 print_help (GOptionContext *context,
 	    gboolean        main_help,
@@ -1149,6 +1150,11 @@ parse_arg (GOptionContext *context,
 
 	retval = (* (GOptionArgFunc) entry->arg_data) (option_name, data, group->user_data, error);
 	
+	if (!retval && error != NULL && *error == NULL)
+	  g_set_error (error, 
+		       G_OPTION_ERROR, G_OPTION_ERROR_FAILED,
+		       _("Error parsing option %s"), option_name);
+
 	g_free (data);
 	
 	return retval;
@@ -1199,8 +1205,8 @@ parse_arg (GOptionContext *context,
 static gboolean
 parse_short_option (GOptionContext *context,
 		    GOptionGroup   *group,
-		    gint            index,
-		    gint           *new_index,
+		    gint            idx,
+		    gint           *new_idx,
 		    gchar           arg,
 		    gint           *argc,
 		    gchar        ***argv,
@@ -1222,7 +1228,7 @@ parse_short_option (GOptionContext *context,
 	    value = NULL;
 	  else
 	    {
-	      if (*new_index > index)
+	      if (*new_idx > idx)
 		{
 		  g_set_error (error, 
 			       G_OPTION_ERROR, G_OPTION_ERROR_FAILED,
@@ -1231,27 +1237,27 @@ parse_short_option (GOptionContext *context,
 		  return FALSE;
 		}
 
-	      if (index < *argc - 1)
+	      if (idx < *argc - 1)
 		{
 		  if (!OPTIONAL_ARG (&group->entries[j]))	
 		    {    
-		      value = (*argv)[index + 1];
-		      add_pending_null (context, &((*argv)[index + 1]), NULL);
-		      *new_index = index+1;
+		      value = (*argv)[idx + 1];
+		      add_pending_null (context, &((*argv)[idx + 1]), NULL);
+		      *new_idx = idx + 1;
 		    }
 		  else
 		    {
-                      if ((*argv)[index + 1][0] == '-') 
+                      if ((*argv)[idx + 1][0] == '-') 
 			value = NULL;
 		      else
 		        {
-		          value = (*argv)[index + 1];
-		          add_pending_null (context, &((*argv)[index + 1]), NULL);
-		          *new_index = index + 1;
+		          value = (*argv)[idx + 1];
+		          add_pending_null (context, &((*argv)[idx + 1]), NULL);
+		          *new_idx = idx + 1;
 			}
 	            }
 		}
-	      else if (index >= *argc - 1 && OPTIONAL_ARG (&group->entries[j]))
+	      else if (idx >= *argc - 1 && OPTIONAL_ARG (&group->entries[j]))
 		value = NULL;
 	      else
 		{
@@ -1281,7 +1287,7 @@ parse_short_option (GOptionContext *context,
 static gboolean
 parse_long_option (GOptionContext *context,
 		   GOptionGroup   *group,
-		   gint           *index,
+		   gint           *idx,
 		   gchar          *arg,
 		   gboolean        aliased,
 		   gint           *argc,
@@ -1293,7 +1299,7 @@ parse_long_option (GOptionContext *context,
 
   for (j = 0; j < group->n_entries; j++)
     {
-      if (*index >= *argc)
+      if (*idx >= *argc)
 	return TRUE;
 
       if (aliased && (group->entries[j].flags & G_OPTION_FLAG_NOALIAS))
@@ -1303,14 +1309,17 @@ parse_long_option (GOptionContext *context,
 	  strcmp (arg, group->entries[j].long_name) == 0)
 	{
 	  gchar *option_name;
+	  gboolean retval;
 
 	  option_name = g_strconcat ("--", group->entries[j].long_name, NULL);
-	  parse_arg (context, group, &group->entries[j],
-		     NULL, option_name, error);
+	  retval = parse_arg (context, group, &group->entries[j],
+			      NULL, option_name, error);
 	  g_free(option_name);
 	  
-	  add_pending_null (context, &((*argv)[*index]), NULL);
+	  add_pending_null (context, &((*argv)[*idx]), NULL);
 	  *parsed = TRUE;
+
+	  return retval;
 	}
       else
 	{
@@ -1322,22 +1331,22 @@ parse_long_option (GOptionContext *context,
 	      gchar *value = NULL;
 	      gchar *option_name;
 
-	      add_pending_null (context, &((*argv)[*index]), NULL);
+	      add_pending_null (context, &((*argv)[*idx]), NULL);
 	      option_name = g_strconcat ("--", group->entries[j].long_name, NULL);
 
 	      if (arg[len] == '=')
 		value = arg + len + 1;
-	      else if (*index < *argc - 1) 
+	      else if (*idx < *argc - 1) 
 		{
 		  if (!(group->entries[j].flags & G_OPTION_FLAG_OPTIONAL_ARG))	
 		    {    
-		      value = (*argv)[*index + 1];
-		      add_pending_null (context, &((*argv)[*index + 1]), NULL);
-		      (*index)++;
+		      value = (*argv)[*idx + 1];
+		      add_pending_null (context, &((*argv)[*idx + 1]), NULL);
+		      (*idx)++;
 		    }
 		  else
 		    {
-                      if ((*argv)[*index + 1][0] == '-') 
+                      if ((*argv)[*idx + 1][0] == '-') 
 		        {
 		          gboolean retval;
 		          retval = parse_arg (context, group, &group->entries[j],
@@ -1348,13 +1357,13 @@ parse_long_option (GOptionContext *context,
 		        }
 		      else
 		        {
-		          value = (*argv)[*index + 1];
-		          add_pending_null (context, &((*argv)[*index + 1]), NULL);
-		          (*index)++;
+		          value = (*argv)[*idx + 1];
+		          add_pending_null (context, &((*argv)[*idx + 1]), NULL);
+		          (*idx)++;
 			}
 	            }
 		}
-	      else if (*index >= *argc - 1 &&
+	      else if (*idx >= *argc - 1 &&
 		       group->entries[j].flags & G_OPTION_FLAG_OPTIONAL_ARG)
 		{
 		    gboolean retval;
@@ -1392,7 +1401,7 @@ parse_long_option (GOptionContext *context,
 static gboolean
 parse_remaining_arg (GOptionContext *context,
 		     GOptionGroup   *group,
-		     gint           *index,
+		     gint           *idx,
 		     gint           *argc,
 		     gchar        ***argv,
 		     GError        **error,
@@ -1402,7 +1411,7 @@ parse_remaining_arg (GOptionContext *context,
 
   for (j = 0; j < group->n_entries; j++)
     {
-      if (*index >= *argc)
+      if (*idx >= *argc)
 	return TRUE;
 
       if (group->entries[j].long_name[0])
@@ -1412,9 +1421,9 @@ parse_remaining_arg (GOptionContext *context,
                             group->entries[j].arg == G_OPTION_ARG_STRING_ARRAY ||
 			    group->entries[j].arg == G_OPTION_ARG_FILENAME_ARRAY, FALSE);
       
-      add_pending_null (context, &((*argv)[*index]), NULL);
+      add_pending_null (context, &((*argv)[*idx]), NULL);
       
-      if (!parse_arg (context, group, &group->entries[j], (*argv)[*index], "", error))
+      if (!parse_arg (context, group, &group->entries[j], (*argv)[*idx], "", error))
 	return FALSE;
       
       *parsed = TRUE;
@@ -1620,8 +1629,6 @@ g_option_context_parse (GOptionContext   *context,
 			print_help (context, FALSE, NULL);		      
 		      else if (strncmp (arg, "help-", 5) == 0)
 			{
-			  GList *list;
-			  
 			  list = context->groups;
 			  
 			  while (list)
@@ -1692,7 +1699,7 @@ g_option_context_parse (GOptionContext   *context,
 		}
 	      else
 		{ /* short option */
-		  gint j, new_i = i, arg_length;
+		  gint new_i = i, arg_length;
 		  gboolean *nulled_out = NULL;
 		  arg = (*argv)[i] + 1;
                   arg_length = strlen (arg);
@@ -2005,9 +2012,8 @@ g_option_group_set_parse_hooks (GOptionGroup     *group,
  * Associates a function with @group which will be called 
  * from g_option_context_parse() when an error occurs.
  *
- * Note that the user data to be passed to @pre_parse_func and
- * @post_parse_func can be specified when constructing the group
- * with g_option_group_new().
+ * Note that the user data to be passed to @error_func can be
+ * specified when constructing the group with g_option_group_new().
  *
  * Since: 2.6
  **/
@@ -2100,7 +2106,7 @@ g_option_group_set_translation_domain (GOptionGroup *group,
  * (see g_option_context_set_description()).
  *
  * If you are using gettext(), you only need to set the translation
- * domain, see g_context_group_set_translation_domain().
+ * domain, see g_option_context_set_translation_domain().
  *
  * Since: 2.12
  **/
@@ -2153,7 +2159,8 @@ g_option_context_set_translation_domain (GOptionContext *context,
  * program functionality. 
  *
  * Note that the summary is translated (see 
- * g_option_context_set_translate_func(), g_option_context_set_translation_domain()).
+ * g_option_context_set_translate_func() and
+ * g_option_context_set_translation_domain()).
  *
  * Since: 2.12
  */
